
/* Chrysalide - Outil d'analyse de fichiers binaires
 * class.c - équivalent Python du fichier "format/dex/class.c"
 *
 * Copyright (C) 2012 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  OpenIDA is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  OpenIDA is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "class.h"


#include <pygobject.h>


#include <format/dex/class.h>



/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Fournit un accès à une définition de type à diffuser.        *
*                                                                             *
*  Retour      : Définition d'objet pour Python.                              *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

PyTypeObject *get_python_dex_class_type(void)
{
    static PyMethodDef py_dex_class_methods[] = {
        { NULL }
    };

    static PyGetSetDef py_dex_class_getseters[] = {
        { NULL }
    };

    static PyTypeObject py_dex_class_type = {

        PyVarObject_HEAD_INIT(NULL, 0)

        .tp_name        = "pychrysalide.format.dex.DexClass",
        .tp_basicsize   = sizeof(PyGObject),

        .tp_flags       = Py_TPFLAGS_DEFAULT,

        .tp_doc         = "PyChrysalide Dex class.",

        .tp_methods     = py_dex_class_methods,
        .tp_getset      = py_dex_class_getseters

    };

    return &py_dex_class_type;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : module = module dont la définition est à compléter.          *
*                                                                             *
*  Description : Prend en charge l'objet 'pychrysalide.format.dex.DexClass'.  *
*                                                                             *
*  Retour      : Bilan de l'opération.                                        *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

bool register_python_dex_class(PyObject *module)
{
    PyTypeObject *py_dex_class_type;        /* Type Python 'DexClass'      */
    int ret;                                /* Bilan d'un appel            */
    PyObject *dict;                         /* Dictionnaire du module      */

    py_dex_class_type = get_python_dex_class_type();

    py_dex_class_type->tp_base = &PyGObject_Type;
    py_dex_class_type->tp_basicsize = py_dex_class_type->tp_base->tp_basicsize;

    if (PyType_Ready(py_dex_class_type) != 0)
        return false;

    Py_INCREF(py_dex_class_type);
    ret = PyModule_AddObject(module, "DexClass", (PyObject *)py_dex_class_type);
    if (ret != 0) return false;

    dict = PyModule_GetDict(module);
    pygobject_register_class(dict, "DexClass", G_TYPE_DEX_CLASS, py_dex_class_type,
                             Py_BuildValue("(O)", py_dex_class_type->tp_base));

    return true;

}
