
/* Chrysalide - Outil d'analyse de fichiers binaires
 * executable.c - équivalent Python du fichier "format/executable.h"
 *
 * Copyright (C) 2010-2013 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  OpenIDA is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  OpenIDA is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "executable.h"


#include <pygobject.h>


#include <format/format.h>


#include "format.h"



/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Fournit un accès à une définition de type à diffuser.        *
*                                                                             *
*  Retour      : Définition d'objet pour Python.                              *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

PyTypeObject *get_python_executable_format_type(void)
{
    static PyMethodDef py_exe_format_methods[] = {
        { NULL }
    };

    static PyGetSetDef py_exe_format_getseters[] = {
        { NULL }
    };

    static PyTypeObject py_exe_format_type = {

        PyVarObject_HEAD_INIT(NULL, 0)

        .tp_name        = "pychrysalide.format.ExeFormat",
        .tp_basicsize   = sizeof(PyGObject),

        .tp_flags       = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,

        .tp_doc         = "PyChrysalide executable format",

        .tp_methods     = py_exe_format_methods,
        .tp_getset      = py_exe_format_getseters,

    };

    return &py_exe_format_type;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : module = module dont la définition est à compléter.          *
*                                                                             *
*  Description : Prend en charge l'objet 'pychrysalide.format.ExeFormat'.     *
*                                                                             *
*  Retour      : Bilan de l'opération.                                        *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

bool register_python_executable_format(PyObject *module)
{
    PyTypeObject *py_exe_format_type;       /* Type Python 'ExeFormat'     */
    int ret;                                /* Bilan d'un appel            */
    PyObject *dict;                         /* Dictionnaire du module      */

    py_exe_format_type = get_python_executable_format_type();

    py_exe_format_type->tp_base = get_python_binary_format_type();
    py_exe_format_type->tp_basicsize = py_exe_format_type->tp_base->tp_basicsize;

    if (PyType_Ready(py_exe_format_type) != 0)
        return false;

    Py_INCREF(py_exe_format_type);
    ret = PyModule_AddObject(module, "ExeFormat", (PyObject *)py_exe_format_type);
    if (ret != 0) return false;

    dict = PyModule_GetDict(module);
    pygobject_register_class(dict, "ExeFormat", G_TYPE_EXE_FORMAT, py_exe_format_type,
                             Py_BuildValue("(O)", py_exe_format_type->tp_base));

    return true;

}
