
/* Chrysalide - Outil d'analyse de fichiers binaires
 * helpers.h - prototypes pour la simplification des interactions de base avec Python
 *
 * Copyright (C) 2012-2013 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  OpenIDA is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  OpenIDA is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _PLUGINS_HELPERS_H
#define _PLUGINS_HELPERS_H


#include <Python.h>
#include <stdbool.h>



/* Indique si une routine Python existe ou non. */
bool has_python_method(PyObject *, const char *);

/* Appelle une routine Python. */
PyObject *_run_python_method(PyObject *, PyObject *);

/* Appelle une routine Python. */
PyObject *run_python_method(PyObject *, const char *, PyObject *);

/* Ajoute une constante au dictionnaire d'un type Python donné. */
bool PyDict_AddIntConstant(PyTypeObject *, const char *, long);

/* Ajoute une constante au dictionnaire d'un type Python donné. */
bool PyDict_AddStringConstant(PyTypeObject *, const char *, const char *);


#define PyDict_AddIntMacro(tp, c) PyDict_AddIntConstant(tp, #c, c)
#define PyDict_AddStringMacro(tp, c) PyDict_AddStringConstant(tp, #c, c)


/**
 * Quelque chose est mal fait au niveau de l'abstraction GObject.
 * Du coup, Py_TPFLAGS_IS_ABSTRACT n'est pas pris en compte.
 * On force alors la méthode de base pour obtenir un traitement correct.
 *
 * Cf. http://stackoverflow.com/questions/20432335/can-python-abstract-base-classes-inherit-from-c-extensions
 */
#define APPLY_ABSTRACT_FLAG(tp) tp->tp_new = PyBaseObject_Type.tp_new



#endif  /* _PLUGINS_HELPERS_H */
