
/* Chrysalide - Outil d'analyse de fichiers binaires
 * pseudo.h - prototypes pour la définition des pseudo-registres
 *
 * Copyright (C) 2010-2013 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  OpenIDA is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  OpenIDA is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _DECOMP_EXPR_PSEUDO_H
#define _DECOMP_EXPR_PSEUDO_H


#include <glib-object.h>


#include "../instruction.h"
#include "../../analysis/variable.h"



#define G_TYPE_PSEUDO_REGISTER               g_pseudo_register_get_type()
#define G_PSEUDO_REGISTER(obj)               (G_TYPE_CHECK_INSTANCE_CAST((obj), g_pseudo_register_get_type(), GPseudoRegister))
#define G_IS_PSEUDO_REGISTER(obj)            (G_TYPE_CHECK_INSTANCE_TYPE((obj), g_pseudo_register_get_type()))
#define G_PSEUDO_REGISTER_CLASS(klass)       (G_TYPE_CHECK_CLASS_CAST((klass), G_TYPE_PSEUDO_REGISTER, GPseudoRegisterClass))
#define G_IS_PSEUDO_REGISTER_CLASS(klass)    (G_TYPE_CHECK_CLASS_TYPE((klass), G_TYPE_PSEUDO_REGISTER))
#define G_PSEUDO_REGISTER_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_PSEUDO_REGISTER, GPseudoRegisterClass))



/* Types de pseudo-registre */
typedef enum _PseudoRegUsage
{
    PRU_THIS,                               /* "this" pour les objets      */
    PRU_ARG,                                /* Argument de fonction        */
    PRU_LOCAL,                              /* Variable locale             */
    PRU_FIXED                               /* Variable type champ         */

} PseudoRegUsage;


/* Définition d'un pseudo-registre (instance) */
typedef struct _GPseudoRegister GPseudoRegister;

/* Définition d'un pseudo-registre (classe) */
typedef struct _GPseudoRegisterClass GPseudoRegisterClass;


/* Indique le type défini pour un pseudo-registre. */
GType g_pseudo_register_get_type(void);

/* Assigne le contenu d'une expression dans une autre. */
GDecInstruction *g_pseudo_register_new(PseudoRegUsage);

/* Indique l'usage attendu du pseudo-registre consulté. */
PseudoRegUsage g_pseudo_register_get_usage(const GPseudoRegister *);

/* Définit un nom général pour un pseudo-registre donné. */
void g_pseudo_register_set_basename(GPseudoRegister *, const char *);

/* Définit un indice unique pour un pseudo-registre donné. */
void g_pseudo_register_set_index(GPseudoRegister *, size_t);

/* Précise le nom et le type de la variable. */
void g_pseudo_register_set_variable(GPseudoRegister *, GBinVariable *);



#endif  /* _DECOMP_EXPR_PSEUDO_H */
