
/* Chrysalide - Outil d'analyse de fichiers binaires
 * editem-int.h - prototypes pour les définitions internes liées aux éléments réactifs de l'éditeur
 *
 * Copyright (C) 2010-2013 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  OpenIDA is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  OpenIDA is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef _GUI_EDITEM_INT_H
#define _GUI_EDITEM_INT_H


#include "editem.h"


#include <gtk/gtkwidget.h>


#include "../common/dllist.h"
#include "../gtkext/gtkbufferview.h"
#include "../gtkext/gtkviewpanel.h"



/* Réagit à un changement du binaire courant. */
typedef void (* update_item_binary_fc) (GEditorItem *, GLoadedBinary *);

/* Réagit à un changement d'affichage principal de contenu. */
typedef void (* update_item_view_fc) (GEditorItem *, GtkViewPanel *);

/* Réagit à un changement de focus des panneaux d'affichage. */
typedef void (* notify_focus_change_fc) (GEditorItem *, GtkViewPanel *);

/* Suit les changements de position dans du code d'assembleur. */
typedef void (* track_caret_in_view_fc) (GEditorItem *, GtkViewPanel *, const vmpa2t *);

/* Concentre l'attention de l'ensemble sur une adresse donnée. */
typedef void (* focus_addr_fc) (GEditorItem *, GLoadedBinary *, const vmpa2t *);

/* Lance une actualisation relative à l'étendue du projet. */
typedef void (* update_project_fc) (GEditorItem *, GStudyProject *);


/* Elément réactif quelconque de l'éditeur (instance) */
struct _GEditorItem
{
    GObject parent;                         /* A laisser en premier        */

    DL_LIST_ITEM(link);                     /* Maillon de liste chaînée    */

    GObject *ref;                           /* Espce de référencement      */

    const char *name;                       /* Nom du panneau              */
    GtkWidget *widget;                      /* Composant GTK d'affichage   */

};


/* Elément réactif quelconque de l'éditeur (classe) */
struct _GEditorItemClass
{
    GObjectClass parent;                    /* A laisser en premier        */

    update_item_binary_fc update_binary;    /* Changement de binaire       */
    update_item_view_fc update_view;        /* Rechargement dû à une vue   */
    update_item_view_fc update_content;     /* Rechargement dû à un contenu*/
    notify_focus_change_fc notify_focus;    /* Gain ou perte de focus      */
    track_caret_in_view_fc track_caret;     /* Suivi des positions         */
    focus_addr_fc focus_addr;               /* Prête attention à une addr. */
    update_project_fc update_project;       /* Actualisation des binaires  */

};


#define editem_list_add_tail(new, head) dl_list_add_tail(new, head, GEditorItem, link) 
#define editem_list_for_each(pos, head) dl_list_for_each(pos, head, GEditorItem, link) 



#endif  /* _GUI_EDITEM_INT_H */
